@@ -9,7 +9,6 @@ import os
 import configparser  # 这个用于读取文件，写入文件会将中文注释删除
 from XZGUtil.logger import conlog
 from XZGUtil.timeUtil import get_now_date, getdate
-from configobj import ConfigObj
 
 proDir = os.path.split(os.path.realpath(__file__))[0]
 
@@ -23,7 +22,6 @@ class upconfig(object):
         self.updatePath = os.path.join(path if path else proDir, f"{file_name}.ini")
         self.config = configparser.RawConfigParser()
         self.config.read(self.updatePath, encoding="utf-8-sig")
-        self.set_config = ConfigObj(self.updatePath, encoding="utf-8-sig")
         self.update_tag = update_tag
 
     def get_information(self, name):
@@ -45,13 +43,13 @@ class upconfig(object):
         :return:
         """
         try:
-            self.set_config[self.update_tag][f'{name}'] = date
-        except KeyError:
+            self.config.set(self.update_tag, f'{name}', date)
+        except configparser.NoSectionError:
             with open(self.updatePath, 'a') as f:
                 f.write(f"[{self.update_tag}]")
-            self.set_config = ConfigObj(self.updatePath, encoding="utf-8-sig")
-        self.set_config[self.update_tag][f'{name}'] = date
-        self.set_config.write()
+            self.config.read(self.updatePath, encoding="utf-8-sig")
+            self.config.set(self.update_tag, f'{name}', date)
+        self.config.write(open(self.updatePath, 'w', encoding='utf-8-sig'))
         conlog(f'{self.update_tag}   *   {name}  *   ', f"更新完成_{date} ")
 
     def check_update(self, name, difference: int = 0):
